==> whizard-2.4.1.tar.gz: whizard-2.4.1/src/whizard-core/rt_data_ut.f90 <==
! WHIZARD 2.4.1 Mar 24 2017
!
! Copyright (C) 1999-2017 by
!     Wolfgang Kilian <kilian@physik.uni-siegen.de>
!     Thorsten Ohl <ohl@physik.uni-wuerzburg.de>
!     Juergen Reuter <juergen.reuter@desy.de>
!
!     with contributions from
!     Fabian Bach <fabian.bach@t-online.de>
!     Bijan Chokoufe <bijan.chokoufe@desy.de>
!     Christian Speckner <cnspeckn@googlemail.com>
!     So Young Shim <soyoung.shim@desy.de>
!     Florian Staub <florian.staub@cern.ch>
!     Christian Weiss <christian.weiss@desy.de>
!     and Hans-Werner Boschmann, Felix Braam,
!     Sebastian Schmidt, So-young Shim, Daniel Wiesler
!
! WHIZARD is free software; you can redistribute it and/or modify it
! under the terms of the GNU General Public License as published by
! the Free Software Foundation; either version 2, or (at your option)
! any later version.
!
! WHIZARD is distributed in the hope that it will be useful, but
! WITHOUT ANY WARRANTY; without even the implied warranty of
! MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
! GNU General Public License for more details.
!
! You should have received a copy of the GNU General Public License
! along with this program; if not, write to the Free Software
! Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
!
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
! This file has been stripped of most comments.  For documentation, refer
! to the source 'whizard.nw'

module rt_data_ut
  use unit_tests
  use rt_data_uti

  implicit none
  private

  public :: rt_data_test

contains

  subroutine rt_data_test (u, results)
    integer, intent(in) :: u
    type(test_results_t), intent(inout) :: results
    call test (rt_data_1, "rt_data_1", &
         "initialize", &
         u, results)
    call test (rt_data_2, "rt_data_2", &
         "fill", &
         u, results)
    call test (rt_data_3, "rt_data_3", &
         "save/restore", &
         u, results)
    call test (rt_data_4, "rt_data_4", &
         "show variables", &
         u, results)
    call test (rt_data_5, "rt_data_5", &
         "show parts", &
         u, results)
    call test (rt_data_6, "rt_data_6", &
         "local model", &
         u, results)
    call test (rt_data_7, "rt_data_7", &
         "result variables", &
         u, results)
    call test (rt_data_8, "rt_data_8", &
         "beam energy", &
         u, results)
    call test (rt_data_9, "rt_data_9", &
         "local variables", &
         u, results)
  end subroutine rt_data_test


end module rt_data_ut

==> whizard-2.6.4.tar.gz: whizard-2.6.4/src/whizard-core/rt_data_ut.f90 <==
! WHIZARD 2.6.4 Aug 23 2018
!
! Copyright (C) 1999-2018 by
!     Wolfgang Kilian <kilian@physik.uni-siegen.de>
!     Thorsten Ohl <ohl@physik.uni-wuerzburg.de>
!     Juergen Reuter <juergen.reuter@desy.de>
!
!     with contributions from
!     cf. main AUTHORS file
!
! WHIZARD is free software; you can redistribute it and/or modify it
! under the terms of the GNU General Public License as published by
! the Free Software Foundation; either version 2, or (at your option)
! any later version.
!
! WHIZARD is distributed in the hope that it will be useful, but
! WITHOUT ANY WARRANTY; without even the implied warranty of
! MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
! GNU General Public License for more details.
!
! You should have received a copy of the GNU General Public License
! along with this program; if not, write to the Free Software
! Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
!
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
! This file has been stripped of most comments.  For documentation, refer
! to the source 'whizard.nw'

module rt_data_ut
  use unit_tests
  use rt_data_uti

  implicit none
  private

  public :: rt_data_test

contains

  subroutine rt_data_test (u, results)
    integer, intent(in) :: u
    type(test_results_t), intent(inout) :: results
    call test (rt_data_1, "rt_data_1", &
         "initialize", &
         u, results)
    call test (rt_data_2, "rt_data_2", &
         "fill", &
         u, results)
    call test (rt_data_3, "rt_data_3", &
         "save/restore", &
         u, results)
    call test (rt_data_4, "rt_data_4", &
         "show variables", &
         u, results)
    call test (rt_data_5, "rt_data_5", &
         "show parts", &
         u, results)
    call test (rt_data_6, "rt_data_6", &
         "local model", &
         u, results)
    call test (rt_data_7, "rt_data_7", &
         "result variables", &
         u, results)
    call test (rt_data_8, "rt_data_8", &
         "beam energy", &
         u, results)
    call test (rt_data_9, "rt_data_9", &
         "local variables", &
         u, results)
    call test(rt_data_10, "rt_data_10", &
              "descriptions", u, results)
    call test(rt_data_11, "rt_data_11", &
              "export objects", u, results)
  end subroutine rt_data_test


end module rt_data_ut
